@@ -15,7 +15,6 @@
 #'          sub_method = "Walktrap",
 #'          confirm_subgroup = NULL,
 #'          paths       = NULL,
-#'          exogenous   = NULL,
 #'          conv_vars   = NULL,
 #'          conv_length = 16, 
 #'          conv_interval = 1,
@@ -31,8 +30,8 @@
 #'          lv_estimator     = "miiv",     
 #'          lv_scores        = "regression",       
 #'          lv_miiv_scaling  = "first.indicator", 
-#'          lv_final_estimator = "miiv", 
-#'          hybrid = FALSE)
+#'          lv_final_estimator = "miiv",
+#'          lasso_model_crit    = NULL)
 #' @param data The path to the directory where the data files are located,
 #' or the name of the list containing each individual's time series. Each file
 #' or matrix must contain one matrix for each individual containing a T (time)
@@ -59,14 +58,7 @@
 #' by the column number. If a
 #' header is used, variables should be referred to using variable names.
 #' To reference lag variables, "lag" should be added to the end of the variable
-#' name with no separation. Defaults to NULL. #### Need to explain mult_vars too. ####
-#' @param exogenous Vector of variable names to be treated as exogenous (optional).
-#' That is, exogenous variable X can predict Y but cannot be predicted by Y.
-#' If no header is used, then variables should be referred to with V followed
-#' (with no separation) by the column number.  If a header is used, variables should be referred 
-#' to using variable names. The default for exogenous variables is that lagged effects of the exogenous 
-#' variables are not included in the model search.  If lagged paths are wanted, "&lag" should be added to the end of the variable
-#' name with no separation. Defaults to NULL.
+#' name with no separation. Defaults to NULL. 
 #' @param conv_vars Vector of variable names to be convolved via smoothed Finite Impulse 
 #' Response (sFIR). Note, conv_vars are not not automatically considered exogenous variables.
 #' To treat conv_vars as exogenous use the exogenous argument. Variables listed in conv_vars 
@@ -137,8 +129,8 @@
 #' "first.indicator" (Default; the first observed variable in the measurement equation is used), "group" 
 #' (best one for the group), or "individual" (each individual has the best one for them according to R2). 
 #' @param lv_final_estimator Estimator for final estimations. "miiv" (Default) or "pml" (pseudo-ML). 
-#' @param hybrid Logical. If TRUE, enables hybrid-VAR models where both directed contemporaneous paths and contemporaneous 
-#' covariances among residuals are candidate relations in the search space. Defaults to FALSE.
+#' @param lasso_model_crit When not null, invokes multiLASSO approach for the GIMME model search procedure. Arguments 
+#' indicate the model selection criterion to use for model selection: 'bic' (select on BIC), 'aic', 'aicc', 'hqc', 'cv' (cross-validation). 
 #' @details
 #'  In main output directory:
 #'  \itemize{
@@ -224,7 +216,6 @@ gimmeSEM <- gimme <- function(data             = NULL,
                               sub_method       = "Walktrap",
                               confirm_subgroup = NULL,
                               paths            = NULL,
-                              exogenous        = NULL,
                               conv_vars        = NULL,
                               conv_length      = 16, 
                               conv_interval    = 1, 
@@ -241,14 +232,17 @@ gimmeSEM <- gimme <- function(data             = NULL,
                               lv_scores        = "regression",       # c("regression", "bartlett")
                               lv_miiv_scaling  = "first.indicator",  # c("group", "individual")
                               lv_final_estimator = "miiv",
-                              hybrid           = FALSE){          # c("miiv", "pml")
+                              lasso_model_crit = NULL){          # c("miiv", "pml")
+  
+  hybrid <- FALSE
 
   # satisfy CRAN checks
   ind     = NULL
   varnames = NULL
   lvarnames = NULL
   sub_membership = NULL
-
+  exogenous        = NULL
+  
   setupConvolve = NULL
   ts = NULL
   setupFinalDataChecks = NULL
@@ -261,8 +255,8 @@ gimmeSEM <- gimme <- function(data             = NULL,
   }
   
   if(ms_allow & ar){
-    writeLines("gimme WARNING: Multiple solutions not likely when ar=TRUE.",
-                " We recommend setting ar to FALSE.")
+    writeLines("gimme WARNING: Multiple solutions are not likely when ar=TRUE.",
+                " We recommend setting ar to FALSE if using ms_allow.")
   }
   
   #Error check for hybrid
@@ -272,7 +266,49 @@ gimmeSEM <- gimme <- function(data             = NULL,
   }
   
    sub_membership = NULL
-
+   
+   # if !is.null(lasso_model_crit)
+   # {
+   #   if(!is.null(mult_vars)){
+   #   ml <- strsplit(mult_vars, "*", fixed = TRUE)
+   #   
+   #   # identify which are exogenous and list those in 'interact_exogenous', then identify 'interact_with_exogneous'
+   #   
+   #   ## something like the below but not quite: 
+   #   #interact_exogenous <- exogenous[regexpr(ml, exogenous)<0]
+   #  # interact_with_exogenous <- ml[regexpr(ml, exogenous)<0]
+   #   
+   #   } else{
+   #     interatct_exogenous <- NULL
+   #     interact_with_exogenous <- NULL
+   #     }
+   #    
+   #   multiLASSO(data                       = data,
+   #              out                        = out,
+   #              sep                        = sep,
+   #              header                     = header,
+   #              ar                         = ar,
+   #              plot                       = plot,
+   #              conv_vars                  = conv_vars,
+   #              conv_length                = conv_length,
+   #              conv_interval              = conv_interval,
+   #              #mult_vars                  = mult_vars,
+   #              # mean_center_mult          = FALSE,
+   #              # standardize               = FALSE,
+   #              groupcutoff                = groupcutoff,
+   #              alpha                      = .5,
+   #              model_crit                 = lasso_model_crit,
+   #              penalties                  = NULL,
+   #              test_penalties             = FALSE,
+   #              exogenous                  = exogenous,
+   #              lag_exogenous              = FALSE,
+   #              interact_exogenous         = interact_exogenous, 
+   #              interact_with_exogenous    = interact_with_exogenous,
+   #              predict_with_interactions  = NULL)
+   #   
+   # } else {
+   hybrid = FALSE
+   
   dat         <- setup(data                 = data,
                        sep                  = sep,
                        header               = header,
@@ -559,7 +595,6 @@ gimmeSEM <- gimme <- function(data             = NULL,
                        diagnos = diagnos,
                        store)
   
-    # these objects are used in both the print.gimmep and
     # plot.gimmep convenience functions. 
     # if you change an object name here, 
     # please check plot.gimmep and print.gimmep
@@ -652,3 +687,4 @@ print.gimme <- function(x, y, z){
     writeLines(paste("Modularity =", round(x$modularity, digits = 5)))
   }
 }
+
