@@ -3,7 +3,9 @@
 subgroupStage <- function(dat,
                           grp,
                           confirm_subgroup,
+                          elig_paths,
                           sub_feature,
+                          sub_method,
                           ms_tol,
                           ms_allow){
 # Satisfy CRAN checks
@@ -14,10 +16,11 @@ subgroupStage <- function(dat,
                                n_subj       = dat$n_subj,
                                chisq_cutoff = dat$chisq_cutoff_mi_epc,
                                file_order   = dat$file_order,
-                               elig_paths   = dat$candidate_paths,
+                               elig_paths   = elig_paths,
                                confirm_subgroup = confirm_subgroup,
                                out_path     = dat$out, 
-                               sub_feature  = sub_feature)
+                               sub_feature  = sub_feature,
+                               sub_method   = sub_method)
 
   # begin subgroup-level search for paths ------------------------------------ #
 
@@ -39,7 +42,7 @@ subgroupStage <- function(dat,
                          add_syntax   = character(),
                          n_paths      = 0,
                          data_list    = dat$ts_list[sub_s$sub_s_subjids],
-                         elig_paths   = dat$candidate_paths,
+                         elig_paths   = elig_paths,
                          prop_cutoff  = dat$sub_cutoff,
                          n_subj       = sub_s$n_sub_subj,
                          chisq_cutoff = qchisq(1-.05/sub_s$n_sub_subj, 1),
@@ -111,7 +114,7 @@ subgroupStage <- function(dat,
                            n_paths      = sub_spec[[s]]$n_sub_paths,
                            data_list    =
                              dat$ts_list[sub_spec[[s]]$sub_s_subjids],
-                           elig_paths   = dat$candidate_paths,
+                           elig_paths   = elig_paths,
                            prop_cutoff  = dat$sub_cutoff,
                            n_subj       = sub_spec[[s]]$n_sub_subj,
                            chisq_cutoff =
